@@ -3,7 +3,7 @@
 
     This file is part of KMail, the KDE mail client.
     SPDX-FileCopyrightText: 2002 Marc Mutz <mutz@kde.org>
-    SPDX-FileCopyrightText: 2014-2022 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2014-2023 Laurent Montel <montel@kde.org>
 
     SPDX-License-Identifier: GPL-2.0-only
 */
@@ -14,7 +14,6 @@
 #include "identityfolderrequester.h"
 #include "identityinvalidfolder.h"
 
-
 #include <QGpgME/Job>
 #include <QGpgME/Protocol>
 
@@ -40,7 +39,7 @@
 #include <KIdentityManagement/SignatureConfigurator>
 
 #include <PimCommon/PimUtil>
-#include <PimCommonAutoCorrection/AutoCorrectionLanguage>
+#include <TextAutoCorrection/AutoCorrectionLanguage>
 
 #include <Libkdepim/LineEditCatchReturnKey>
 #include <PimCommonAkonadi/AddresseeLineEdit>
@@ -90,8 +89,8 @@ using MailTransport::TransportManager;
 #include <Akonadi/EntityDisplayAttribute>
 #include <Akonadi/SpecialMailCollections>
 #include <QDialogButtonBox>
-#include <QStandardPaths>
 #include <QGroupBox>
+#include <QStandardPaths>
 
 using namespace KPIM;
 using namespace MailTransport;
@@ -393,13 +392,12 @@ IdentityDialog::IdentityDialog(QWidget *parent)
             mPGPEncryptionKeyRequester->setCurrentKey(key);
         }
     });
-    connect(mPGPSigningKeyRequester, &KeySelectionCombo::customItemSelected, this, [&](const QVariant& type) {
+    connect(mPGPSigningKeyRequester, &KeySelectionCombo::customItemSelected, this, [&](const QVariant &type) {
         if (mPGPSameKey->isChecked() && type == QLatin1String("no-key")) {
             mPGPEncryptionKeyRequester->setCurrentIndex(mPGPSigningKeyRequester->currentIndex());
         }
     });
 
-
     // "OpenPGP Encryption Key" requester and label:
     mPGPEncryptionKeyRequester = new KeySelectionCombo(KeySelectionCombo::EncryptionKey, GpgME::OpenPGP, mCryptographyTab);
     msg = i18n(
@@ -614,7 +612,7 @@ IdentityDialog::IdentityDialog(QWidget *parent)
     connect(mEditVCard, &QPushButton::clicked, this, &IdentityDialog::slotEditVcard);
     formLayout->addRow(mAttachMyVCard, mEditVCard);
 
-    mAutoCorrectionLanguage = new PimCommonAutoCorrection::AutoCorrectionLanguage(tab);
+    mAutoCorrectionLanguage = new TextAutoCorrection::AutoCorrectionLanguage(tab);
     label = new QLabel(i18n("Autocorrection language:"), tab);
     label->setBuddy(mAutoCorrectionLanguage);
     formLayout->addRow(label, mAutoCorrectionLanguage);
