@@ -52,8 +52,7 @@ namespace TemplateParser
 {
 class TemplatesConfiguration;
 }
-
-namespace PimCommonAutoCorrection
+namespace TextAutoCorrection
 {
 class AutoCorrectionLanguage;
 }
@@ -127,7 +126,7 @@ private:
     MailTransport::TransportComboBox *mTransportCombo = nullptr;
     QCheckBox *mAttachMyVCard = nullptr;
     QPushButton *mEditVCard = nullptr;
-    PimCommonAutoCorrection::AutoCorrectionLanguage *mAutoCorrectionLanguage = nullptr;
+    TextAutoCorrection::AutoCorrectionLanguage *mAutoCorrectionLanguage = nullptr;
     QLineEdit *mDefaultDomainEdit = nullptr;
 
     // "templates" tab:
