@@ -53,8 +53,8 @@ using KMail::MailServiceImpl;
 #include <MessageList/MessageListUtil>
 #include <MessageViewer/MessageViewerSettings>
 #include <PimCommon/NetworkManager>
-#include <PimCommonAutoCorrection/AutoCorrection>
-#include <PimCommonAutoCorrection/PimCommonAutoCorrectionSettings>
+#include <TextAutoCorrection/AutoCorrection>
+#include <TextAutoCorrection/TextAutoCorrectionSettings>
 #include <gravatar/gravatarsettings.h>
 #include <messagelist/messagelistsettings.h>
 
@@ -93,6 +93,7 @@ using KMail::MailServiceImpl;
 
 #include <QDir>
 #include <QFileInfo>
+#include <QTextCodec>
 #include <QWidget>
 #include <QtDBus>
 
@@ -109,13 +110,16 @@ using KMail::MailServiceImpl;
 #include "searchdialog/searchdescriptionattribute.h"
 #ifdef WITH_KUSERFEEDBACK
 #include "userfeedback/kmailuserfeedbackprovider.h"
+#ifdef USE_KUSERFEEDBACK_QT6
+#include <KUserFeedbackQt6/Provider>
+#else
 #include <KUserFeedback/Provider>
 #endif
+#endif
 #include <chrono>
-#include <kwidgetsaddons_version.h>
 
 using namespace std::chrono_literals;
-//#define DEBUG_SCHEDULER 1
+// #define DEBUG_SCHEDULER 1
 using namespace MailCommon;
 
 static KMKernel *mySelf = nullptr;
@@ -151,8 +155,7 @@ KMKernel::KMKernel(QObject *parent)
     // so better do it here, than in some code where changing the group of config()
     // would be unexpected
     KMailSettings::self();
-
-    mAutoCorrection = new PimCommonAutoCorrection::AutoCorrection();
+    mAutoCorrection = new TextAutoCorrection::AutoCorrection();
     KMime::setUseOutlookAttachmentEncoding(MessageComposer::MessageComposerSettings::self()->outlookCompatibleAttachments());
 
     // cberzan: this crap moved to CodecManager ======================
@@ -801,7 +804,7 @@ void KMKernel::pauseBackgroundJobs()
 void KMKernel::resumeBackgroundJobs()
 {
     mJobScheduler->resume();
-    mBackgroundTasksTimer->start(4 * 60 * 60 * 1000);
+    mBackgroundTasksTimer->start(4h);
 }
 
 void KMKernel::stopNetworkJobs()
@@ -940,11 +943,7 @@ bool KMKernel::askToGoOnline()
 
     if (KMailSettings::self()->networkState() == KMailSettings::EnumNetworkState::Offline) {
         s_askingToGoOnline = true;
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
         int rc = KMessageBox::questionTwoActions(KMKernel::self()->mainWin(),
-#else
-        int rc = KMessageBox::questionYesNo(KMKernel::self()->mainWin(),
-#endif
                                                  i18n("KMail is currently in offline mode. "
                                                       "How do you want to proceed?"),
                                                  i18n("Online/Offline"),
@@ -952,11 +951,7 @@ bool KMKernel::askToGoOnline()
                                                  KGuiItem(i18n("Work Offline")));
 
         s_askingToGoOnline = false;
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
         if (rc == KMessageBox::ButtonCode::SecondaryAction) {
-#else
-        if (rc == KMessageBox::No) {
-#endif
             return false;
         } else {
             kmkernel->resumeNetworkJobs();
@@ -1296,7 +1291,7 @@ void KMKernel::slotSyncConfig()
 {
     saveConfig();
     // Laurent investigate why we need to reload them.
-    PimCommonAutoCorrection::PimCommonAutoCorrectionSettings::self()->load();
+    TextAutoCorrection::TextAutoCorrectionSettings::self()->load();
     MessageCore::MessageCoreSettings::self()->load();
     MessageViewer::MessageViewerSettings::self()->load();
     MessageComposer::MessageComposerSettings::self()->load();
@@ -1311,7 +1306,7 @@ void KMKernel::slotSyncConfig()
 
 void KMKernel::saveConfig()
 {
-    PimCommonAutoCorrection::PimCommonAutoCorrectionSettings::self()->save();
+    TextAutoCorrection::TextAutoCorrectionSettings::self()->save();
     MessageCore::MessageCoreSettings::self()->save();
     MessageViewer::MessageViewerSettings::self()->save();
     MessageComposer::MessageComposerSettings::self()->save();
@@ -1442,8 +1437,9 @@ KSharedConfig::Ptr KMKernel::config()
 
         mMailCommonSettings->setSharedConfig(mySelf->mConfig);
         mMailCommonSettings->load();
-        PimCommonAutoCorrection::PimCommonAutoCorrectionSettings::self()->setSharedConfig(mySelf->mConfig);
-        PimCommonAutoCorrection::PimCommonAutoCorrectionSettings::self()->load();
+
+        TextAutoCorrection::TextAutoCorrectionSettings::self()->setSharedConfig(mySelf->mConfig);
+        TextAutoCorrection::TextAutoCorrectionSettings::self()->load();
         Gravatar::GravatarSettings::self()->setSharedConfig(mySelf->mConfig);
         Gravatar::GravatarSettings::self()->load();
     }
@@ -1512,9 +1508,9 @@ void KMKernel::slotRunBackgroundTasks() // called regularly by timer
         mCheckIndexingManager->start(entityTreeModel());
     }
 #ifdef DEBUG_SCHEDULER // for debugging, see jobscheduler.h
-    mBackgroundTasksTimer->start(60 * 1000); // check again in 1 minute
+    mBackgroundTasksTimer->start(1m); // check again in 1 minute
 #else
-    mBackgroundTasksTimer->start(4 * 60 * 60 * 1000); // check again in 4 hours
+    mBackgroundTasksTimer->start(4h); // check again in 4 hours
 #endif
 }
 
@@ -1994,8 +1990,7 @@ void KMKernel::makeResourceOnline(MessageViewer::Viewer::ResourceOnlineMode mode
         break;
     }
 }
-
-PimCommonAutoCorrection::AutoCorrection *KMKernel::composerAutoCorrection()
+TextAutoCorrection::AutoCorrection *KMKernel::composerAutoCorrection()
 {
     return mAutoCorrection;
 }
